import android.content.Context
import android.net.Uri
import android.util.Log
import com.google.vr.sdk.widgets.video.VrVideoEventListener
import com.google.vr.sdk.widgets.video.VrVideoView
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.FlutterPlugin.FlutterPluginBinding
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.*
import io.flutter.plugin.common.PluginRegistry.Registrar
import io.flutter.plugin.platform.PlatformView
import io.flutter.plugin.platform.PlatformViewFactory
import java.io.File


class MyFlutterView(context: Context, messenger: BinaryMessenger, viewId: Int, args: Map<String, Any>?) :
        PlatformView,MethodChannel.MethodCallHandler, VrVideoEventListener() {

    private val videoView: VrVideoView = VrVideoView(context)
    private val videoViewOptions: VrVideoView.Options = VrVideoView.Options()
    private var methodChannel: MethodChannel
    private lateinit var uri: Uri
    init {
        try {
            args?.also{
        //            Log.d("MyFlutterView","$it")
                videoViewOptions.inputType = VrVideoView.Options.TYPE_MONO
                videoViewOptions.inputFormat=VrVideoView.Options.FORMAT_DEFAULT
                videoView.setFullscreenButtonEnabled (false); //隐藏全屏模式按钮
                videoView.setInfoButtonEnabled(false) //设置隐藏最左边信息的按钮
                videoView.setStereoModeButtonEnabled(false); //设置隐藏立体模型的按钮
                videoView.displayMode=1
                videoView.setEventListener(this)//设置监听
                //加载本地的图片源
                uri = Uri.fromFile(File("${it["path"]}"));
                videoView.loadVideo(uri,videoViewOptions)
            }
        } catch (error:Exception){
            Log.e("MyFlutterView", "Could not open video: $error");
        }
        methodChannel = MethodChannel(messenger, "com.flutter.ys.YSVRView")
        methodChannel.setMethodCallHandler(this)
    }

    override fun getView(): VrVideoView {
        return videoView
    }

    override fun dispose() {
        videoView.pauseRendering()
        videoView.shutdown()
    }

    override fun onMethodCall(call: MethodCall, result: MethodChannel.Result) {
        if (call.method == "putType") {
            val type = call.argument("type") as String?
            Log.i("onMethodCall", "putType------------>$type")
            if (type=="1"){
                videoViewOptions.inputType = VrVideoView.Options.TYPE_MONO
            }else if (type=="2"){
                videoViewOptions.inputType = VrVideoView.Options.TYPE_STEREO_OVER_UNDER
            }
            videoView.loadVideo(uri,videoViewOptions)
//            result.success({})
        }else if (call.method == "watchType") {
            val type = call.argument("type") as String?
            Log.i("onMethodCall", "watchType------------>$type")
            if (type=="1"){
                videoView.displayMode=3
            }else if (type=="2"){
                videoView.displayMode=0
            }
        } else {
            result.notImplemented()
        }
    }

    override fun onLoadSuccess() {
        Log.i("ActivityEventListener", "onLoadSuccess------------>")
    }

    override fun onLoadError(errorMessage: String) {
        Log.i("ActivityEventListener", "Error loading pano:------------> $errorMessage")
    }

    override fun onClick() { //当我们点击了VrPanoramaView 时候出发
        super.onClick()
        Log.i("ActivityEventListener", "onClick------------>")
    }

    override fun onDisplayModeChanged(newDisplayMode: Int) {
        //改变显示模式时候出发（全屏模式和纸板模式）
        super.onDisplayModeChanged(newDisplayMode)
        Log.i("ActivityEventListener", "onDisplayModeChanged------------>$newDisplayMode")
    }

    override fun onCompletion() {
        Log.i("ActivityEventListener", "onCompletion------------>")
        videoView.seekTo(0)
        super.onCompletion()
    }
}

class FlutterPanoramaPlugin : FlutterPlugin, ActivityAware {
    private var flutterPluginBinding: FlutterPluginBinding? = null
    override fun onAttachedToEngine(binding: FlutterPluginBinding) {
        flutterPluginBinding = binding
    }

    override fun onDetachedFromEngine(binding: FlutterPluginBinding) {
        flutterPluginBinding = null
    }

    override fun onAttachedToActivity(binding: ActivityPluginBinding) {
        val messenger = flutterPluginBinding!!.binaryMessenger
        flutterPluginBinding!!
                .platformViewRegistry
                .registerViewFactory(
                        "plugins.flutter.io/ys_vr_player_view", FlutterPanoramaFactory(binding.activity, messenger))
    }

    override fun onDetachedFromActivityForConfigChanges() {
//    onDetachedFromActivity();
    }

    override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
//    onAttachedToActivity(binding);
    }

    override fun onDetachedFromActivity() {}

    companion object {
        fun registerWith(registrar: Registrar) {
            registrar
                    .platformViewRegistry()
                    .registerViewFactory(
                            "plugins.flutter.io/ys_vr_player_view",
                            FlutterPanoramaFactory(registrar.activeContext(), registrar.messenger()))
        }
    }
}

class FlutterPanoramaFactory internal constructor(private val context: Context, private val messenger: BinaryMessenger) : PlatformViewFactory(StandardMessageCodec.INSTANCE) {
    override fun create(context1: Context, viewId: Int, args: Any?): PlatformView {
        val params = args as Map<String, Any>?
        // args是由Flutter传过来的自定义参数
        return MyFlutterView(context, messenger, viewId, params)
    }
}

